==> nextcloud-12.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/es_EC.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Comentarios",
    "Unknown user" : "Usuario desconocido",
    "New comment …" : "Comentario nuevo ...",
    "Delete comment" : "Borrar comentario",
    "Post" : "Publicar",
    "Cancel" : "Cancelar",
    "Edit comment" : "Editar comentario",
    "[Deleted user]" : "[Usuario borrado]",
    "No comments yet, start the conversation!" : "¡Aún no hay comentarios, inicia la conversación!",
    "More comments …" : "Más comentarios ...",
    "Save" : "Guardar",
    "Allowed characters {count} of {max}" : "Caracteres permitidos {count} de {max}",
    "Error occurred while retrieving comment with id {id}" : "Se presentó un error al recuperar el comentario con Id {id}",
    "Error occurred while updating comment with id {id}" : "Se presentó un error al actualizar el comentario con Id {id}",
    "Error occurred while posting comment" : "Se presentó un error al publicar el comentario",
    "_%n unread comment_::_%n unread comments_" : ["%n comentarios sin leer","%n comentarios sin leer"],
    "Comment" : "Comentario",
    "You commented" : "Comentaste",
    "%1$s commented" : "%1$s comentó",
    "{author} commented" : "{author} comentó",
    "You commented on %1$s" : "Usted comentó en %1$s",
    "You commented on {file}" : "Hiciste un comentario de {file}",
    "%1$s commented on %2$s" : "%1$s comentó en %2$s",
    "{author} commented on {file}" : "{author} comentó en {file}",
    "<strong>Comments</strong> for files" : "<strong>Comentarios</strong> de los archivos",
    "You were mentioned on “%s”, in a comment by a user that has since been deleted" : "Te mencionaron en \"%s\", en un comentario de un usuario que ya ha sido borrado",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Te mencionaron en \"{file}\", en un comentario de un usuario que ya ha sido borrado",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s te mencionó en un comentario en “%2$s”",
    "{user} mentioned you in a comment on “{file}”" : "{user} te mencionó en un comentario en “{file}”",
    "A (now) deleted user mentioned you in a comment on “%s”" : "Un usuario (ahora) borrado te mencionó en un commentario en “%s”",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "Un usuario (ahora) borrado te mencionó en un commentario en “{file}”"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-13.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/es_EC.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Comentarios",
    "Edit comment" : "Editar comentario",
    "Delete comment" : "Borrar comentario",
    "New comment …" : "Comentario nuevo ...",
    "Post" : "Publicar",
    "Cancel" : "Cancelar",
    "[Deleted user]" : "[Usuario borrado]",
    "No comments yet, start the conversation!" : "¡Aún no hay comentarios, inicia la conversación!",
    "More comments …" : "Más comentarios ...",
    "Save" : "Guardar",
    "Allowed characters {count} of {max}" : "Caracteres permitidos {count} de {max}",
    "Error occurred while retrieving comment with ID {id}" : "Se presentó un error al recuperar el comentario con ID {id}",
    "Error occurred while updating comment with id {id}" : "Se presentó un error al actualizar el comentario con Id {id}",
    "Error occurred while posting comment" : "Se presentó un error al publicar el comentario",
    "_%n unread comment_::_%n unread comments_" : ["%n comentarios sin leer","%n comentarios sin leer"],
    "Comment" : "Comentario",
    "You commented" : "Comentaste",
    "%1$s commented" : "%1$s comentó",
    "{author} commented" : "{author} comentó",
    "You commented on %1$s" : "Usted comentó en %1$s",
    "You commented on {file}" : "Hiciste un comentario de {file}",
    "%1$s commented on %2$s" : "%1$s comentó en %2$s",
    "{author} commented on {file}" : "{author} comentó en {file}",
    "<strong>Comments</strong> for files" : "<strong>Comentarios</strong> de los archivos",
    "You were mentioned on “%s”, in a comment by a user that has since been deleted" : "Te mencionaron en \"%s\", en un comentario de un usuario que ya ha sido borrado",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Te mencionaron en \"{file}\", en un comentario de un usuario que ya ha sido borrado",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s te mencionó en un comentario en “%2$s”",
    "{user} mentioned you in a comment on “{file}”" : "{user} te mencionó en un comentario en “{file}”",
    "Unknown user" : "Usuario desconocido",
    "A (now) deleted user mentioned you in a comment on “%s”" : "Un usuario (ahora) borrado te mencionó en un commentario en “%s”",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "Un usuario (ahora) borrado te mencionó en un commentario en “{file}”"
},
"nplurals=2; plural=(n != 1);");
